(v0.10.9)=
### 0.10.9 {small}`2024-08-28`

#### Bug fixes

- Fix writing large number of columns for `h5` files {user}`ilan-gold` {user}`selmanozleyen` ({pr}`1147`)
- Add warning for setting `X` on a view with repeated indices {user}`ilan-gold` ({pr}`1501`)
- Coerce {class}`numpy.matrix` classes to arrays when trying to store them in `AnnData` {user}`flying-sheep` ({pr}`1516`)
- Fix for setting a dense `X` view with a sparse matrix {user}`ilan-gold` ({pr}`1532`)
- Upper bound {mod}`numpy` for `gpu` installation on account of {issue}`cupy/cupy#8391` {user}`ilan-gold` ({pr}`1540`)
- Upper bound dask on account of {issue}`1579` {user}`ilan-gold` ({pr}`1580`)
- Ensure setting {attr}`pandas.DataFrame.index` on a view of a {class}`~anndata.AnnData` instantiates the {class}`~pandas.DataFrame` from the view {user}`ilan-gold` ({pr}`1586`)
- Disallow using {class}`~pandas.DataFrame`s with multi-index columns {user}`ilan-gold` ({pr}`1589`)

#### Development Process

- create new `cupy` installation options for cuda 11 & 12 called `cu11` and `cu12` {user}`Intron7` ({pr}`1596`)

#### Documentation

- add `callback` typing for {func}`~anndata.experimental.read_dispatched` and {func}`~anndata.experimental.write_dispatched` {user}`ilan-gold` ({pr}`1557`)

#### Performance

- Support for `concat_on_disk` outer join {user}`ilan-gold` ({pr}`1504`)
